@@ -13,12 +13,12 @@ import collections
 import os
 import requests
 import folium
-import here_map_widget
 import ipyleaflet
 import xyzservices.providers as xyz
-from box import Box
 from .common import check_package, planet_tiles
 
+# from box import Box
+
 # Custom XYZ tile services.
 xyz_tiles = {
     "OpenStreetMap": {
@@ -131,13 +131,29 @@ wms_tiles = {
         "transparent": True,
     },
     "USGS NAIP Imagery": {
-        "url": "https://services.nationalmap.gov/arcgis/services/USGSNAIPImagery/ImageServer/WMSServer?",
-        "layers": "0",
+        "url": "https://imagery.nationalmap.gov/arcgis/services/USGSNAIPImagery/ImageServer/WMSServer?",
+        "layers": "USGSNAIPImagery:NaturalColor",
         "name": "USGS NAIP Imagery",
         "attribution": "USGS",
         "format": "image/png",
         "transparent": True,
     },
+    "USGS NAIP Imagery False Color": {
+        "url": "https://imagery.nationalmap.gov/arcgis/services/USGSNAIPImagery/ImageServer/WMSServer?",
+        "layers": "USGSNAIPImagery:FalseColorComposite",
+        "name": "USGS NAIP Imagery False Color",
+        "attribution": "USGS",
+        "format": "image/png",
+        "transparent": True,
+    },
+    "USGS NAIP Imagery NDVI": {
+        "url": "https://imagery.nationalmap.gov/arcgis/services/USGSNAIPImagery/ImageServer/WMSServer?",
+        "layers": "USGSNAIPImagery:NDVI_Color",
+        "name": "USGS NAIP Imagery NDVI",
+        "attribution": "USGS",
+        "format": "image/png",
+        "transparent": True,
+    },
     "USGS Hydrography": {
         "url": "https://basemap.nationalmap.gov/arcgis/services/USGSHydroCached/MapServer/WMSServer?",
         "layers": "0",
@@ -154,62 +170,62 @@ wms_tiles = {
         "format": "image/png",
         "transparent": True,
     },
+    "ESA WorldCover 2020": {
+        "url": "https://services.terrascope.be/wms/v2",
+        "layers": "WORLDCOVER_2020_MAP",
+        "name": "ESA Worldcover 2020",
+        "attribution": "ESA",
+        "format": "image/png",
+        "transparent": True,
+    },
+    "ESA WorldCover 2020 S2 FCC": {
+        "url": "https://services.terrascope.be/wms/v2",
+        "layers": "WORLDCOVER_2020_S2_FCC",
+        "name": "ESA Worldcover 2020 S2 FCC",
+        "attribution": "ESA",
+        "format": "image/png",
+        "transparent": True,
+    },
+    "ESA WorldCover 2020 S2 TCC": {
+        "url": "https://services.terrascope.be/wms/v2",
+        "layers": "WORLDCOVER_2020_S2_TCC",
+        "name": "ESA Worldcover 2020 S2 TCC",
+        "attribution": "ESA",
+        "format": "image/png",
+        "transparent": True,
+    },
+    "ESA WorldCover 2021": {
+        "url": "https://services.terrascope.be/wms/v2",
+        "layers": "WORLDCOVER_2021_MAP",
+        "name": "ESA Worldcover 2021",
+        "attribution": "ESA",
+        "format": "image/png",
+        "transparent": True,
+    },
+    "ESA WorldCover 2021 S2 FCC": {
+        "url": "https://services.terrascope.be/wms/v2",
+        "layers": "WORLDCOVER_2021_S2_FCC",
+        "name": "ESA Worldcover 2021 S2 FCC",
+        "attribution": "ESA",
+        "format": "image/png",
+        "transparent": True,
+    },
+    "ESA WorldCover 2021 S2 TCC": {
+        "url": "https://services.terrascope.be/wms/v2",
+        "layers": "WORLDCOVER_2021_S2_TCC",
+        "name": "ESA Worldcover 2021 S2 TCC",
+        "attribution": "ESA",
+        "format": "image/png",
+        "transparent": True,
+    },
 }
 
-# Built-in heremap tile services.
-here_tiles = {
-    "HERE_RASTER_NORMAL_MAP": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.normal.map
-    ),
-    "HERE_RASTER_NORMAL_BASE": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.normal.base
-    ),
-    "HERE_RASTER_NORMAL_BASE_NIGHT": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.normal.basenight
-    ),
-    "HERE_RASTER_NORMAL_LABELS": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.normal.labels
-    ),
-    "HERE_RASTER_NORMAL_TRANSIT": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.normal.transit
-    ),
-    "HERE_RASTER_NORMAL_XBASE": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.normal.xbase
-    ),
-    "HERE_RASTER_NORMAL_XBASE_NIGHT": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.normal.xbasenight
-    ),
-    "HERE_RASTER_SATELLITE_MAP": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.satellite.map
-    ),
-    "HERE_RASTER_SATELLITE_LABELS": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.satellite.labels
-    ),
-    "HERE_RASTER_SATELLITE_BASE": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.satellite.base
-    ),
-    "HERE_RASTER_SATELLITE_XBASE": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.satellite.xbase
-    ),
-    "HERE_RASTER_TERRAIN_MAP": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.terrain.map
-    ),
-    "HERE_RASTER_TERRAIN_LABELS": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.terrain.labels
-    ),
-    "HERE_RASTER_TERRAIN_BASE": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.terrain.base
-    ),
-    "HERE_RASTER_TERRAIN_XBASE": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.raster.terrain.xbase
-    ),
-    "HERE_VECTOR_NORMAL_MAP": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.vector.normal.map
-    ),
-    "HERE_VECTOR_NORMAL_TRUCK": here_map_widget.DefaultLayers(
-        layer_name=here_map_widget.DefaultLayerNames.vector.normal.truck
-    ),
-}
+
+def _unpack_sub_parameters(var, param):
+    temp = var
+    for sub_param in param.split("."):
+        temp = getattr(temp, sub_param)
+    return temp
 
 
 def get_xyz_dict(free_only=True):
@@ -226,8 +242,8 @@ def get_xyz_dict(free_only=True):
     for item in xyz.values():
         try:
             name = item["name"]
-            tile = eval("xyz." + name)
-            if eval("xyz." + name + ".requires_token()"):
+            tile = _unpack_sub_parameters(xyz, name)
+            if _unpack_sub_parameters(xyz, name).requires_token():
                 if free_only:
                     pass
                 else:
@@ -238,8 +254,8 @@ def get_xyz_dict(free_only=True):
         except Exception:
             for sub_item in item:
                 name = item[sub_item]["name"]
-                tile = eval("xyz." + name)
-                if eval("xyz." + name + ".requires_token()"):
+                tile = _unpack_sub_parameters(xyz, name)
+                if _unpack_sub_parameters(xyz, name).requires_token():
                     if free_only:
                         pass
                     else:
@@ -415,6 +431,69 @@ def xyz_to_heremap():
     Returns:
         dict: A dictionary of heremap tile layers.
     """
+
+    try:
+        import here_map_widget
+    except ImportError:
+        raise ImportError(
+            'This module requires the hermap package. Please install it using "pip install here-map-widget-for-jupyter".'
+        )
+
+    # Built-in heremap tile services.
+    here_tiles = {
+        "HERE_RASTER_NORMAL_MAP": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.normal.map
+        ),
+        "HERE_RASTER_NORMAL_BASE": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.normal.base
+        ),
+        "HERE_RASTER_NORMAL_BASE_NIGHT": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.normal.basenight
+        ),
+        "HERE_RASTER_NORMAL_LABELS": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.normal.labels
+        ),
+        "HERE_RASTER_NORMAL_TRANSIT": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.normal.transit
+        ),
+        "HERE_RASTER_NORMAL_XBASE": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.normal.xbase
+        ),
+        "HERE_RASTER_NORMAL_XBASE_NIGHT": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.normal.xbasenight
+        ),
+        "HERE_RASTER_SATELLITE_MAP": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.satellite.map
+        ),
+        "HERE_RASTER_SATELLITE_LABELS": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.satellite.labels
+        ),
+        "HERE_RASTER_SATELLITE_BASE": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.satellite.base
+        ),
+        "HERE_RASTER_SATELLITE_XBASE": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.satellite.xbase
+        ),
+        "HERE_RASTER_TERRAIN_MAP": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.terrain.map
+        ),
+        "HERE_RASTER_TERRAIN_LABELS": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.terrain.labels
+        ),
+        "HERE_RASTER_TERRAIN_BASE": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.terrain.base
+        ),
+        "HERE_RASTER_TERRAIN_XBASE": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.raster.terrain.xbase
+        ),
+        "HERE_VECTOR_NORMAL_MAP": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.vector.normal.map
+        ),
+        "HERE_VECTOR_NORMAL_TRUCK": here_map_widget.DefaultLayers(
+            layer_name=here_map_widget.DefaultLayerNames.vector.normal.truck
+        ),
+    }
+
     heremap_dict = {}
 
     for key in xyz_tiles:
@@ -447,6 +526,75 @@ def xyz_to_heremap():
     return heremap_dict
 
 
+def xyz_to_plotly():
+    """Convert xyz tile services to plotly tile layers.
+
+    Returns:
+        dict: A dictionary of plotly tile layers.
+    """
+    plotly_dict = {}
+
+    for key in xyz_tiles:
+        url = xyz_tiles[key]["url"]
+        attribution = xyz_tiles[key]["attribution"]
+        plotly_dict[key] = {
+            "below": "traces",
+            "sourcetype": "raster",
+            "sourceattribution": attribution,
+            "source": [url],
+            "name": key,
+        }
+
+    xyz_dict = get_xyz_dict()
+    for item in xyz_dict:
+        name = xyz_dict[item].name
+        url = xyz_dict[item].build_url()
+        attribution = xyz_dict[item].attribution
+
+        plotly_dict[name] = {
+            "below": "traces",
+            "sourcetype": "raster",
+            "sourceattribution": attribution,
+            "source": [url],
+            "name": name,
+        }
+
+    return plotly_dict
+
+
+def xyz_to_bokeh():
+    """Convert xyz tile services to bokeh tile layers.
+
+    Returns:
+        dict: A dictionary of bokeh tile layers.
+    """
+    from bokeh.models import WMTSTileSource
+
+    bokeh_dict = {}
+
+    for key in xyz_tiles:
+        url = xyz_tiles[key]["url"]
+        attribution = xyz_tiles[key]["attribution"]
+        tile_options = {
+            "url": url,
+            "attribution": attribution,
+        }
+        bokeh_dict[key] = WMTSTileSource(**tile_options)
+
+    xyz_dict = get_xyz_dict()
+    for item in xyz_dict:
+        url = xyz_dict[item].build_url()
+        attribution = xyz_dict[item].attribution
+        key = xyz_dict[item].name
+        tile_options = {
+            "url": url,
+            "attribution": attribution,
+        }
+        bokeh_dict[key] = WMTSTileSource(**tile_options)
+
+    return bokeh_dict
+
+
 def search_qms(keywords, limit=10):
     """Search qms files for keywords. Reference: https://github.com/geopandas/xyzservices/issues/65
 
@@ -484,14 +632,3 @@ def qms_to_leafmap(service_id):
 
     layer = ipyleaflet.TileLayer(url=url, name=name, attribution=attribution)
     return layer
-
-
-leafmap_basemaps = Box(xyz_to_leaflet(), frozen_box=True)
-folium_basemaps = Box(xyz_to_folium(), frozen_box=True)
-here_basemaps = Box(xyz_to_heremap(), frozen_box=True)
-# try:
-#     import pydeck
-
-#     pydeck_basemaps = Box(xyz_to_pydeck(), frozen_box=True)
-# except ImportError:
-#     pass
