@@ -7,11 +7,22 @@ import os
 import json
 import random
 import requests
-import here_map_widget
+import warnings
 import ipywidgets as widgets
-from .basemaps import here_basemaps
+from box import Box
+from .basemaps import xyz_to_heremap
 from .common import shp_to_geojson, gdf_to_geojson, vector_to_geojson, random_string
+from . import examples
 
+try:
+    import here_map_widget
+except ImportError:
+    raise ImportError(
+        'This module requires the hermap package. Please install it using "pip install here-map-widget-for-jupyter".'
+    )
+
+
+warnings.filterwarnings("ignore")
 from here_map_widget import (
     FullscreenControl,
     MeasurementControl,
@@ -25,6 +36,9 @@ from here_map_widget import (
 )
 
 
+basemaps = Box(xyz_to_heremap(), frozen_box=True)
+
+
 class Map(here_map_widget.Map):
     """
     The Map class inherits here_map_widget.Map. The arguments you can pass to the Map can be found
@@ -44,13 +58,13 @@ class Map(here_map_widget.Map):
                 )
 
         if "center" not in kwargs:
-            kwargs["center"] = [40, -100]
+            kwargs["center"] = [20, 0]
 
         if "zoom" not in kwargs:
-            kwargs["zoom"] = 4
+            kwargs["zoom"] = 2
 
         if "basemap" in kwargs:
-            kwargs["basemap"] = here_basemaps[kwargs["basemap"]]
+            kwargs["basemap"] = basemaps[kwargs["basemap"]]
 
         super().__init__(api_key=api_key, **kwargs)
         self.baseclass = "here_map_widget"
@@ -135,12 +149,12 @@ class Map(here_map_widget.Map):
                     )
                 )
                 self.basemap = layer
-            elif basemap in here_basemaps and here_basemaps[basemap] not in self.layers:
-                self.basemap = here_basemaps[basemap]
+            elif basemap in basemaps and basemaps[basemap] not in self.layers:
+                self.basemap = basemaps[basemap]
         except Exception:
             raise ValueError(
                 "Basemap can only be one of the following:\n  {}".format(
-                    "\n  ".join(here_basemaps.keys())
+                    "\n  ".join(basemaps.keys())
                 )
             )
 
@@ -301,23 +315,26 @@ class Map(here_map_widget.Map):
             value = """{}""".format("".join(value))
             html.value = value
 
-        geojson = GeoJSON(
-            data=data,
-            style=style if style else {},
-            hover_style=hover_style if hover_style else {},
-            style_callback=style_callback,
-            name=layer_name,
-            point_style=point_style if point_style else {},
-            show_bubble=default_popup,
-        )
+        try:
+            geojson = GeoJSON(
+                data=data,
+                style=style if style else {},
+                hover_style=hover_style if hover_style else {},
+                style_callback=style_callback,
+                name=layer_name,
+                point_style=point_style if point_style else {},
+                show_bubble=default_popup,
+            )
 
-        if not default_popup:
-            if info_mode == "on_hover":
-                geojson.on_hover(_update_html)
-            elif info_mode == "on_click":
-                geojson.on_click(_update_html)
+            if not default_popup:
+                if info_mode == "on_hover":
+                    geojson.on_hover(_update_html)
+                elif info_mode == "on_click":
+                    geojson.on_click(_update_html)
 
-        self.add_layer(geojson)
+            self.add_layer(geojson)
+        except Exception as e:
+            print(e)
 
     def add_shp(
         self,
