@@ -7,6 +7,7 @@ import pandas as pd
 from IPython.display import display, HTML
 from .common import *
 from .osm import *
+from . import examples
 
 try:
     import keplergl
@@ -31,19 +32,36 @@ class Map(keplergl.KeplerGl):
     def __init__(self, **kwargs):
 
         if "center" not in kwargs:
-            kwargs["center"] = [40, -100]
+            kwargs["center"] = [20, 0]
 
         if "zoom" not in kwargs:
-            kwargs["zoom"] = 2.97
+            kwargs["zoom"] = 1.3
 
         if "height" not in kwargs:
             kwargs["height"] = 600
         elif "px" in str(kwargs["height"]):
             kwargs["height"] = kwargs["height"].replace("px", "")
 
+        if "width" not in kwargs:
+            kwargs["width"] = 600
+        elif "px" in str(kwargs["width"]):
+            kwargs["width"] = kwargs["width"].replace("px", "")
+
         if "widescreen" not in kwargs:
             kwargs["widescreen"] = False
 
+        if "pitch" not in kwargs:
+            kwargs["pitch"] = 0
+
+        if "bearing" not in kwargs:
+            kwargs["bearing"] = 0
+
+        if "dragRotate" not in kwargs:
+            kwargs["dragRotate"] = False
+
+        if "isSplit" not in kwargs:
+            kwargs["isSplit"] = False
+
         if kwargs["widescreen"]:
             display(HTML("<style>.container { width:100% !important; }</style>"))
 
@@ -54,6 +72,12 @@ class Map(keplergl.KeplerGl):
                     "latitude": kwargs["center"][0],
                     "longitude": kwargs["center"][1],
                     "zoom": kwargs["zoom"],
+                    "bearing": kwargs["bearing"],
+                    "pitch": kwargs["pitch"],
+                    "isSplit": kwargs["isSplit"],
+                    "dragRotate": kwargs["dragRotate"],
+                    "height": kwargs["height"],
+                    "width": kwargs["width"],
                 }
             },
         }
@@ -108,7 +132,20 @@ class Map(keplergl.KeplerGl):
             if isinstance(in_geojson, str):
 
                 if in_geojson.startswith("http"):
-                    data = requests.get(in_geojson).json()
+                    if is_jupyterlite():
+                        import pyodide
+
+                        output = os.path.basename(in_geojson)
+
+                        output = os.path.abspath(output)
+                        obj = pyodide.http.open_url(in_geojson)
+                        with open(output, 'w') as fd:
+                            shutil.copyfileobj(obj, fd)
+                        with open(output, 'r') as fd:
+                            data = json.load(fd)
+                    else:
+                        in_geojson = github_raw_url(in_geojson)
+                        data = requests.get(in_geojson).json()
                 else:
                     in_geojson = os.path.abspath(in_geojson)
                     if not os.path.exists(in_geojson):
