@@ -6,6 +6,7 @@ import os
 import unittest
 import leafmap.foliumap as leafmap
 import geopandas as gpd
+import pandas as pd
 from unittest.mock import patch
 
 
@@ -56,20 +57,20 @@ class TestFoliumap(unittest.TestCase):
         out_str = m.to_html()
         assert "Elevation" in out_str
 
-    @patch("matplotlib.pyplot.show")
-    def test_add_colormap(self, mock_show):
-        """Check colormap"""
-        with self.assertRaises(NotImplementedError):
-            m = leafmap.Map()
-            m.add_colormap(cmap="gray", label="Elevation")
-            out_str = m.to_html()
-            assert "Elevation" in out_str
+    # @patch("matplotlib.pyplot.show")
+    # def test_add_colormap(self, mock_show):
+    #     """Check colormap"""
+    #     with self.assertRaises(NotImplementedError):
+    #         m = leafmap.Map()
+    #         m.add_colormap(cmap="gray", label="Elevation")
+    #         out_str = m.to_html()
+    #         assert "Elevation" in out_str
 
     def test_add_gdf(self):
         """Check GeoDataFrame"""
         m = leafmap.Map()
         gdf = gpd.read_file(
-            "https://github.com/giswqs/leafmap/raw/master/examples/data/cable-geo.geojson"
+            "https://github.com/giswqs/leafmap/raw/master/examples/data/cable_geo.geojson"
         )
         m.add_gdf(gdf, layer_name="Cable lines")
         out_str = m.to_html()
@@ -106,7 +107,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_geojson(self):
         """Check GeoJSON"""
         m = leafmap.Map()
-        in_geojson = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/cable-geo.geojson"
+        in_geojson = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/cable_geo.geojson"
         m.add_geojson(in_geojson, layer_name="Cable lines")
         out_str = m.to_html()
         assert "Cable lines" in out_str
@@ -129,7 +130,7 @@ class TestFoliumap(unittest.TestCase):
     def test_add_kml(self):
         """Check KML"""
         m = leafmap.Map()
-        in_kml = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/us-states.kml"
+        in_kml = "https://raw.githubusercontent.com/giswqs/leafmap/master/examples/data/us_states.kml"
         m.add_kml(in_kml, layer_name="US States KML")
         out_str = m.to_html()
         assert "US States KML" in out_str
@@ -151,13 +152,13 @@ class TestFoliumap(unittest.TestCase):
         out_str = m.to_html()
         assert "NLCD" in out_str
 
-    def test_add_marker_cluster(self):
-        """Check marker cluster"""
-        with self.assertRaises(NotImplementedError):
-            m = leafmap.Map()
-            m.add_marker_cluster()
-            out_str = m.to_html()
-            assert "Marker Cluster" in out_str
+    # def test_add_marker_cluster(self):
+    #     """Check marker cluster"""
+    #     with self.assertRaises(NotImplementedError):
+    #         m = leafmap.Map()
+    #         m.add_marker_cluster()
+    #         out_str = m.to_html()
+    #         assert "Marker Cluster" in out_str
 
     def test_add_minimap(self):
         """Check minimap"""
@@ -196,14 +197,14 @@ class TestFoliumap(unittest.TestCase):
         out_str = m.to_html()
         assert "NYC" in out_str
 
-    def test_add_osm_from_place(self):
-        """Check OSM data from place"""
-        m = leafmap.Map()
-        place = "Bunker Hill, Los Angeles, California"
-        tags = {"building": True}
-        m.add_osm_from_place(place, tags, layer_name="Los Angeles, CA")
-        out_str = m.to_html()
-        assert "Los Angeles, CA" in out_str
+    # def test_add_osm_from_place(self):
+    #     """Check OSM data from place"""
+    #     m = leafmap.Map()
+    #     place = "Bunker Hill, Los Angeles, California"
+    #     tags = {"building": True}
+    #     m.add_osm_from_place(place, tags, layer_name="Los Angeles, CA")
+    #     out_str = m.to_html()
+    #     assert "Los Angeles, CA" in out_str
 
     def test_add_osm_from_point(self):
         """Check OSM data from point"""
@@ -266,25 +267,25 @@ class TestFoliumap(unittest.TestCase):
             out_str = m.to_html()
             assert "US Cities" in out_str
 
-    def test_add_raster(self):
-        """Check loading raster data"""
-        with self.assertRaises(NotImplementedError):
-            m = leafmap.Map()
-            landsat_url = "https://drive.google.com/file/d/1vRkAWQYsLWCi6vcTMk8vLxoXMFbdMFn8/view?usp=sharing"
-            leafmap.download_from_gdrive(landsat_url, "dem.tif", unzip=False)
-            m.add_raster("dem.tif", colormap="terrain", layer_name="DEM")
-            out_str = m.to_html()
-            assert "DEM" in out_str
+    # def test_add_raster(self):
+    #     """Check loading raster data"""
+    #     with self.assertRaises(NotImplementedError):
+    #         m = leafmap.Map()
+    #         landsat_url = "https://drive.google.com/file/d/1vRkAWQYsLWCi6vcTMk8vLxoXMFbdMFn8/view?usp=sharing"
+    #         leafmap.download_from_gdrive(landsat_url, "dem.tif", unzip=False)
+    #         m.add_raster("dem.tif", colormap="terrain", layer_name="DEM")
+    #         out_str = m.to_html()
+    #         assert "DEM" in out_str
 
-    def test_add_shp(self):
-        """Check adding shapefile"""
-        m = leafmap.Map()
-        in_shp = (
-            "https://github.com/giswqs/leafmap/raw/master/examples/data/countries.zip"
-        )
-        m.add_shp(in_shp, layer_name="Countries")
-        out_str = m.to_html()
-        assert "Countries" in out_str
+    # def test_add_shp(self):
+    #     """Check adding shapefile"""
+    #     m = leafmap.Map()
+    #     in_shp = (
+    #         "https://github.com/giswqs/leafmap/raw/master/examples/data/countries.zip"
+    #     )
+    #     m.add_shp(in_shp, layer_name="Countries")
+    #     out_str = m.to_html()
+    #     assert "Countries" in out_str
 
     def test_add_stac_layer(self):
         """Check adding STAC layer"""
@@ -361,6 +362,18 @@ class TestFoliumap(unittest.TestCase):
             out_str = m.to_html()
             assert "World Cities" in out_str
 
+    def test_add_points_from_xy(self):
+        "Check adding point data"
+        m = leafmap.Map()
+        in_csv = (
+            "https://raw.githubusercontent.com/giswqs/data/main/world/world_cities.csv"
+        )
+        m.add_points_from_xy(
+            in_csv, x="longitude", y="latitude", layer_name="World Cities"
+        )
+        out_str = m.to_html()
+        assert "World Cities" in out_str
+
     def test_basemap_demo(self):
         """Check basemap demo"""
         with self.assertRaises(NotImplementedError):
@@ -392,7 +405,7 @@ class TestFoliumap(unittest.TestCase):
         """Check getting scale"""
         with self.assertRaises(NotImplementedError):
             m = leafmap.Map()
-            self.assertEqual(m.get_scale(), 9783.94)
+            self.assertEqual(m.get_scale(), 39135.76)
 
     def test_image_overlay(self):
         """Check image overlay"""
@@ -419,14 +432,6 @@ class TestFoliumap(unittest.TestCase):
         with self.assertRaises(AttributeError):
             m.center
 
-    def test_split_map(self):
-        """Check split-panel map"""
-        with self.assertRaises(NotImplementedError):
-            m = leafmap.Map()
-            m.split_map(left_layer="HYBRID", right_layer="OpenStreetMap")
-            out_str = m.to_html()
-            assert "OpenStreetMap" in out_str
-
     def test_to_html(self):
         """Check map to html"""
         m = leafmap.Map()
@@ -472,7 +477,7 @@ class TestFoliumap(unittest.TestCase):
         """Check zoom to GeoDataFrame"""
         m = leafmap.Map()
         gdf = gpd.read_file(
-            "https://github.com/giswqs/leafmap/raw/master/examples/data/cable-geo.geojson"
+            "https://github.com/giswqs/leafmap/raw/master/examples/data/cable_geo.geojson"
         )
         m.zoom_to_gdf(gdf)
         out_str = m.to_html()
